@@ -1,6 +1,6 @@
 import numpy as np
 
-from typing import List, Tuple
+from typing import List, Tuple, Optional
 
 import json
 
@@ -40,7 +40,8 @@ class TranscriptionPacket(DataPacket, DictSerializable):
 
 
 class Word(DictSerializable):
-    def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: int = 1, confidence: float = 0):
+    def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[int] = None,
+                 confidence: float = 0):
         self.word: str = word
         self.start_time: float = start_time_millis
         self.end_time: float = end_time_millis
